@@ -11,7 +11,8 @@ use warnings;
 use base qw( IO::Async::Notifier );
 IO::Async::Notifier->VERSION( '0.63' ); # adopt_future
 
-our $VERSION = '0.11';
+our $VERSION = '0.12';
+$VERSION = eval $VERSION;
 
 use Carp;
 
@@ -100,6 +101,12 @@ Invoked when the user has now left a room.
 Invoked on receipt of a room invite. The C<$event> will contain the plain
 Matrix event as received; with at least the keys C<inviter> and C<room_id>.
 
+=head2 on_unknown_event $event
+
+Invoked on receipt of any sort of event from the event stream, that is not
+recognised by any of the other code. This can be used to handle new kinds of
+incoming events.
+
 =cut
 
 =head1 PARAMETERS
@@ -176,7 +183,7 @@ sub configure
    my %params = @_;
 
    foreach (qw( server path_prefix ua SSL
-                on_log on_presence on_room_new on_room_del on_invite
+                on_log on_unknown_event on_presence on_room_new on_room_del on_invite
                 on_room_member on_room_message )) {
       $self->{$_} = delete $params{$_} if exists $params{$_};
    }
@@ -486,7 +493,7 @@ sub start
             if( $membership eq "join" ) {
                my $state = $_->{state};
 
-               my $room = $self->_make_room( $room_id );
+               my $room = $self->_get_or_make_room( $room_id );
                $room->_handle_event_initial( $_ ) for @$state;
 
                $room->maybe_invoke_event( on_synced_state => );
@@ -582,11 +589,12 @@ sub _get_or_make_user
 sub _make_room
 {
    my $self = shift;
-   my ( $room_id, @args ) = @_;
+   my ( $room_id ) = @_;
 
    $self->{rooms_by_id}{$room_id} and
       croak "Already have a room with ID '$room_id'";
 
+   my @args;
    foreach (qw( message member )) {
       push @args, "on_$_" => $self->{"on_room_$_"} if $self->{"on_room_$_"};
    }
@@ -612,10 +620,10 @@ sub make_room
 sub _get_or_make_room
 {
    my $self = shift;
-   my ( $room_id, @args ) = @_;
+   my ( $room_id ) = @_;
 
    return $self->{rooms_by_id}{$room_id} //
-      $self->_make_room( $room_id, @args );
+      $self->_make_room( $room_id );
 }
 
 =head2 $user = $matrix->myself
@@ -661,7 +669,9 @@ sub _incoming_event
       unshift @subtype_args, pop @type_parts;
    }
 
-   $self->log( "  incoming event=".pp($event) );
+   $self->maybe_invoke_event(
+      on_unknown_event => $event
+   ) or $self->log( "  incoming event=".pp($event) );
 }
 
 sub _on_self_leave
