@@ -8,7 +8,8 @@ package Net::Async::Matrix::Utils;
 use strict;
 use warnings;
 
-our $VERSION = '0.11';
+our $VERSION = '0.12';
+$VERSION = eval $VERSION;
 
 use Exporter 'import';
 our @EXPORT_OK = qw(
@@ -146,6 +147,7 @@ sub build_formatted_message
    my ( $str ) = @_;
 
    return { body => $str } if !ref $str;
+   return { body => $str->str } if !$str->tagnames;
 
    if( CAN_BUILD_HTML ) {
       my $html = String::Tagged::HTML->clone( $str,
